<?php

/**
 * @file
 * Contains \Drupal\system\Form\RssFeedsForm.
 */

namespace Drupal\social_stats\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\node\Entity\NodeType;
use Drupal\Core\Form\FormStateInterface;

class SocialStatsContentTypeForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return [
      'social_stats.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'social_stats_content_type_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $node_types = NodeType::loadMultiple();
    $config_social_stats = $this->configFactory->get('social_stats.settings');

    // Loop over all the content types to build the config array per content-type.
    foreach ($node_types as $type) {
      $config = unserialize($config_social_stats->get('social_stats_content_types_' . $type->id()));
      $form['social_stats'][$type->label()] = array(
        '#type' => 'details',
        '#title' => $type->label(),
        '#open' => TRUE,
      );
      $form['social_stats'][$type->id()]['social_stats_' . $type->id()] = array(
        '#type' => 'checkboxes',
        '#options' => array(
          'fb' => t('Facebook'),
          'twitter' => t('Twitter'),
          'gplus' => t('Google Plus'),
          'linkedin' => t('LinkedIn'),
        ),
        '#default_value' => unserialize($config_social_stats->get('social_stats_content_types_' . $type->id()))
      );
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $userInputValues = $form_state->getUserInput();
    $node_types = NodeType::loadMultiple();

    $config = $this->config('social_stats.settings');

    // Add new index to the config variable per content type.
    foreach ($node_types as $type) {
      $config->set('social_stats_content_types_' . $type->id(), serialize($userInputValues['social_stats_' . $type->id()]));
    }

    $config->save();
    parent::submitForm($form, $form_state);
  }

}
